using System.Collections.Generic;
using UnityEngine;

namespace SwimmingInVR.Scripts
{
    /// <summary>
    /// Simple scanner, which is triggered by a TriggerEnter event.
    /// Calls the corresponding functions in the scanned objects.
    /// (AudioLog.StartAudioLog, ScannableObject.Scan())
    /// </summary>
    [RequireComponent(typeof(SphereCollider))]
    public class Scanner : MonoBehaviour
    {
        [SerializeField] private List<AudioClip> scannerSounds;
        private AudioSource _audioSource;
        
        // Start is called before the first frame update
        void Start()
        {
            // Collider setup
            var sphereCollider = GetComponent<SphereCollider>();
            if (sphereCollider)
                sphereCollider.isTrigger = true;

            _audioSource = GetComponent<AudioSource>();
        }
        
        private void OnTriggerEnter(Collider other)
        {
            var scannableObject = other.GetComponent<ScannableObject>();
            if (scannableObject) scannableObject.Scan();
            
            var audioLog = other.GetComponent<AudioLog>();
            if (audioLog) audioLog.StartAudioLog();
            
            // Play scan sound when something has been scanned.
            if (audioLog || scannableObject)
            {
                if (_audioSource && scannerSounds.Count > 0)
                {
                    _audioSource.clip = scannerSounds[Random.Range(0, scannerSounds.Count)];
                    _audioSource.Play();
                }
            }
        }
    }
}